@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | eAccelerator project                                                 |
    +----------------------------------------------------------------------+
-   | Copyright (c) 2004 - 2006 eAccelerator                               |
+   | Copyright (c) 2004 - 2010 eAccelerator                               |
    | http://eaccelerator.net                                              |
    +----------------------------------------------------------------------+
    | This program is free software; you can redistribute it and/or        |
@@ -22,20 +22,16 @@
    |                                                                      |
    | A copy is availble at http://www.gnu.org/copyleft/gpl.txt            |
    +----------------------------------------------------------------------+
-   $Id: ea_store.h 176 2006-03-05 12:18:54Z bart $
+   $Id: ea_store.h 375 2010-01-19 15:49:13Z bart $
 */
 
 #ifndef EA_STORE_H
 #define EA_STORE_H
 
-void calc_zval(zval *z TSRMLS_DC);
-int calc_size(char *key, zend_op_array *op_array, Bucket *f, Bucket *c TSRMLS_DC);
-void calc_op_array(zend_op_array *from TSRMLS_DC);
-void calc_class_entry(zend_class_entry *from TSRMLS_DC);
+size_t calc_zval(zval *z TSRMLS_DC);
+size_t calc_size(char *key, zend_op_array *op_array, Bucket *f, Bucket *c TSRMLS_DC);
 
-void store_zval(zval *z TSRMLS_DC);
-eaccelerator_op_array *store_op_array(zend_op_array *from TSRMLS_DC);
-eaccelerator_class_entry *store_class_entry_ptr(zend_class_entry **from TSRMLS_DC);
-eaccelerator_class_entry *store_class_entry(zend_class_entry *from TSRMLS_DC);
+void store_zval(char **p, zval *z TSRMLS_DC);
+void eaccelerator_store_int(ea_cache_entry *entry, char *key, int len, zend_op_array *op_array, Bucket *f, Bucket *c TSRMLS_DC);
 
 #endif /* EA_STORE_H */
