@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | eAccelerator project                                                 |
    +----------------------------------------------------------------------+
-   | Copyright (c) 2004 - 2006 eAccelerator                               |
+   | Copyright (c) 2004 - 2010 eAccelerator                               |
    | http://eaccelerator.net                                              |
    +----------------------------------------------------------------------+
    | This program is free software; you can redistribute it and/or        |
@@ -22,7 +22,7 @@
    |                                                                      |
    | A copy is availble at http://www.gnu.org/copyleft/gpl.txt            |
    +----------------------------------------------------------------------+
-   $Id: mm.h 176 2006-03-05 12:18:54Z bart $
+   $Id: mm.h 376 2010-01-19 16:49:49Z hans $
 */
 
 /* libmm replacement */
@@ -46,7 +46,6 @@ extern "C" {
 #define MM_LOCK_RW 1
 #define MM_LOCK_RD 0
 
-#if (_MSC_VER < 1400)
 MM*    _mm_create(size_t size, const char* key);
 void   _mm_set_attach(MM* mm, void* attach_addr);
 void*  _mm_attach(size_t size, const char* key);
@@ -61,11 +60,11 @@ void   _mm_free_lock(MM* mm, void* p);
 void*  _mm_malloc_nolock(MM* mm, size_t size);
 void   _mm_free_nolock(MM* mm, void* p);
 size_t _mm_sizeof(MM* mm, void* x);
-#endif
 
 
 const char* mm_shm_type();
 const char* mm_sem_type();
+void mm_check_mem(void *x);
 
 #define MM_PROT_NONE  1
 #define MM_PROT_READ  2
@@ -74,7 +73,6 @@ const char* mm_sem_type();
 
 int mm_protect(MM* mm, int mode);
 
-#if (_MSC_VER < 1400)
 #define mm_create(A, B)        _mm_create(A, B)
 #define mm_set_attach(A, B)    _mm_set_attach(A, B)
 #define mm_attach(A, B)        _mm_attach(A, B)
@@ -89,7 +87,6 @@ int mm_protect(MM* mm, int mode);
 #define mm_malloc_nolock(A, B) _mm_malloc_nolock(A, B)
 #define mm_free_nolock(A, B)   _mm_free_nolock(A, B)
 #define mm_sizeof(A, B)        _mm_sizeof(A, B)
-#endif
 
 #ifdef __cplusplus
 }
